package com.xlht.xlhtproject.service.impl;


import com.xlht.xlhtproject.domain.TXinyiMedicineParam;
import com.xlht.xlhtproject.mapper.TXinyiMedicineParamMapper;
import com.xlht.xlhtproject.service.ITXinyiMedicineParamService;
import com.xlht.xlhtproject.utils.DateUtils;
import org.apache.ibatis.annotations.Mapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Objects;


/**
 * 智能投药参数设置Service业务层处理
 * 
 * @author slibra
 * @date 2024-09-09
 */
@Service
public class TXinyiMedicineParamServiceImpl implements ITXinyiMedicineParamService
{
    @Autowired
    private TXinyiMedicineParamMapper tXinyiMedicineParamMapper;

    /*@Autowired
    private TXinyiIndustryMapper xinyiIndustryMapper;*/

    /**
     * 查询智能投药参数设置
     * 
     * @param id 智能投药参数设置主键
     * @return 智能投药参数设置
     */
    @Override
    public TXinyiMedicineParam selectTXinyiMedicineParamById(Long id)
    {
        return tXinyiMedicineParamMapper.selectTXinyiMedicineParamById(id);
    }

    /**
     * 查询智能投药参数设置列表
     * 
     * @param tXinyiMedicineParam 智能投药参数设置
     * @return 智能投药参数设置
     */
    @Override
    public List<TXinyiMedicineParam> selectTXinyiMedicineParamList(TXinyiMedicineParam tXinyiMedicineParam)
    {
        return tXinyiMedicineParamMapper.selectTXinyiMedicineParamList(tXinyiMedicineParam);
    }

    /**
     * 新增智能投药参数设置
     * 
     * @param tXinyiMedicineParam 智能投药参数设置
     * @return 结果
     */
    @Override
    public int insertTXinyiMedicineParam(TXinyiMedicineParam tXinyiMedicineParam)
    {
        tXinyiMedicineParam.setCreateTime(DateUtils.getNowDate());
        return tXinyiMedicineParamMapper.insertTXinyiMedicineParam(tXinyiMedicineParam);
    }

    /**
     * 修改智能投药参数设置
     * 
     * @param tXinyiMedicineParam 智能投药参数设置
     * @return 结果
     */
    @Override
    public int updateTXinyiMedicineParam(TXinyiMedicineParam tXinyiMedicineParam)
    {
        tXinyiMedicineParam.setUpdateTime(DateUtils.getNowDate());
        return tXinyiMedicineParamMapper.updateTXinyiMedicineParam(tXinyiMedicineParam);
    }

    /**
     * 批量删除智能投药参数设置
     * 
     * @param ids 需要删除的智能投药参数设置主键
     * @return 结果
     */
    @Override
    public int deleteTXinyiMedicineParamByIds(Long[] ids)
    {
        return tXinyiMedicineParamMapper.deleteTXinyiMedicineParamByIds(ids);
    }

    /**
     * 删除智能投药参数设置信息
     * 
     * @param id 智能投药参数设置主键
     * @return 结果
     */
    @Override
    public int deleteTXinyiMedicineParamById(Long id)
    {
        return tXinyiMedicineParamMapper.deleteTXinyiMedicineParamById(id);
    }

    @Override
    public TXinyiMedicineParam getLatestRecord() {
        TXinyiMedicineParam latestRecord = this.tXinyiMedicineParamMapper.getLatestRecord();
        //todo 额外查询 碳源投加瞬时流量
        if(!Objects.isNull(latestRecord)){

        }
        return latestRecord;
    }
}
